EXPORTS	
	??1CAttributeLookupTable@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CAttributeLookupTable::~CAttributeLookupTable(void)
	?Debug@CAttributeLookupTable@@QAEXW4TDebugSelectorType@1@PAX1@Z @ 2 NONAME ; public: void __thiscall CAttributeLookupTable::Debug(enum CAttributeLookupTable::TDebugSelectorType,void *,void *)
	?Des2IDL@CAttributeLookupTable@@QAEPBVHBufC16@@ABVTDesC16@@@Z @ 3 NONAME ; public: class HBufC16 const * __thiscall CAttributeLookupTable::Des2IDL(class TDesC16 const &)
	?KeyExists@CAttributeLookupTable@@QAEPBVHBufC16@@ABVTDesC16@@@Z @ 4 NONAME ; public: class HBufC16 const * __thiscall CAttributeLookupTable::KeyExists(class TDesC16 const &)
	?NewL@CAttributeLookupTable@@SAPAV1@XZ @ 5 NONAME ; public: static class CAttributeLookupTable * __cdecl CAttributeLookupTable::NewL(void)
	?Reset@CAttributeLookupTable@@QAEXXZ @ 6 NONAME ; public: void __thiscall CAttributeLookupTable::Reset(void)
	?Stub7@CUrl@@AAEXXZ @ 7 NONAME ; void CUrl::Stub7(void)
	?Stub8@CUrl@@AAEXXZ @ 8 NONAME ; void CUrl::Stub8(void)
	?Stub9@CUrl@@AAEXXZ @ 9 NONAME ; void CUrl::Stub9(void)
	?Stub10@CUrl@@AAEXXZ @ 10 NONAME ; void CUrl::Stub10(void)
	?Stub11@CUrl@@AAEXXZ @ 11 NONAME ; void CUrl::Stub11(void)
	?Stub12@CUrl@@AAEXXZ @ 12 NONAME ; void CUrl::Stub12(void)
	?Stub13@CUrl@@AAEXXZ @ 13 NONAME ; void CUrl::Stub13(void)
	?Stub14@CUrl@@AAEXXZ @ 14 NONAME ; void CUrl::Stub14(void)
	?Stub15@CUrl@@AAEXXZ @ 15 NONAME ; void CUrl::Stub15(void)
	?Stub16@CUrl@@AAEXXZ @ 16 NONAME ; void CUrl::Stub16(void)
	?EscapeDecodeL@CUrl@@SAPAVHBufC16@@ABVTDesC16@@@Z @ 17 NONAME ; class HBufC16 * CUrl::EscapeDecodeL(class TDesC16 const &)
	?Stub18@CUrl@@AAEXXZ @ 18 NONAME ; void CUrl::Stub18(void)
	?Stub19@CUrl@@AAEXXZ @ 19 NONAME ; void CUrl::Stub19(void)
	?Stub20@CUrl@@AAEXXZ @ 20 NONAME ; void CUrl::Stub20(void)
	?Stub21@CUrl@@AAEXXZ @ 21 NONAME ; void CUrl::Stub21(void)
	?EscapeEncodeL@CUrl@@SAPAVHBufC16@@ABVTDesC16@@H@Z @ 22 NONAME ; class HBufC16 * CUrl::EscapeEncodeL(class TDesC16 const &, int)